Re: pack-object poor performance (with large number of objects?)
- From
Piotr Krukowiecki <piotr.krukowiecki@gmail.com>
- Date
- Oct 5, 2011, 08:48 UTC
- Message-ID
- <CAA01CsoZVhbZHQgCsbk=XV833oQCbw-SVv9FuPQ05DFu49c0sQ@mail.gmail.com>
- In-Reply-To
- <20111004180829.GB31671@sigill.intra.peff.net>
On Tue, Oct 4, 2011 at 8:08 PM, Jeff King <peff@peff.net> wrote:
Show 13 quoted lines
> On Tue, Oct 04, 2011 at 03:21:24PM +0200, Piotr Krukowiecki wrote:
>
>> I have 4GB ram + 4GB swap. Is it possible the RAM is the problem if I
>> always have free RAM left and my swap is almost not used?
>> For example at the moment repack finished counting objects ("Counting
>> objects: 1742200, done."):
>>
>> $ free -m
>> total used free shared buffers cached
>> Mem: 3960 3814 146 0 441 215
>> -/+ buffers/cache: 3157 803
>> Swap: 6143 694 5449
>[...]
> I have no idea if this will actually go faster for you. But it might be > worth trying, instead of just redoing the svn import with auto-gc turned > on.
I've left it to run over night and it finished (took almost 12 hours), so hopefully I'm not going to run into this problem anymore.
$ time git repack -a -d -f Counting objects: 1742200, done. Delta compression using up to 4 threads. Compressing objects: 100% (1291909/1291909), done. Writing objects: 100% (1742200/1742200), done. Total 1742200 (delta 1094325), reused 39192 (delta 0) Removing duplicate objects: 100% (256/256), done.
real 704m3.477s user 65m35.960s sys 9m50.880s
$ du -sh .git/objects/pack 3.9G .git/objects/pack
$ git count-objects -v count: 0 size: 0 in-pack: 1742200 packs: 1 size-pack: 4078245 prune-packable: 0 garbage: 0
-- Piotr Krukowiecki